Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func SetVersionInfo ¶
func SetVersionInfo(v, c, d string)
Types ¶
type CheckoutCommand ¶ added in v0.3.1
type CheckoutCommand struct {
// contains filtered or unexported fields
}
CheckoutCommand handles the checkout command logic
func NewCheckoutCommand ¶ added in v0.3.1
func NewCheckoutCommand(deps *Dependencies, copyEnvs, noFetch bool) *CheckoutCommand
NewCheckoutCommand creates a new checkout command handler
func NewCheckoutCommandWithConfig ¶ added in v0.4.0
func NewCheckoutCommandWithConfig(deps *Dependencies, copyEnvs, noFetch bool, cfg *config.Config) *CheckoutCommand
NewCheckoutCommandWithConfig creates a new checkout command handler with explicit config
func (*CheckoutCommand) Execute ¶ added in v0.3.1
func (c *CheckoutCommand) Execute(branch string) error
Execute runs the checkout command
type CleanCommand ¶ added in v0.6.0
type CleanCommand struct {
// contains filtered or unexported fields
}
CleanCommand handles the clean command logic
func NewCleanCommand ¶ added in v0.6.0
func NewCleanCommand(deps *Dependencies, force, dryRun, noFetch bool) *CleanCommand
NewCleanCommand creates a new clean command handler
func NewCleanCommandWithConfig ¶ added in v0.6.0
func NewCleanCommandWithConfig(deps *Dependencies, force, dryRun, noFetch bool, cfg *config.Config) *CleanCommand
NewCleanCommandWithConfig creates a new clean command handler with explicit config
func (*CleanCommand) Execute ¶ added in v0.6.0
func (c *CleanCommand) Execute() error
Execute runs the clean command
type Dependencies ¶ added in v0.3.1
type Dependencies struct {
Git git.Interface
UI ui.Interface
Detect detect.Interface
Stdout io.Writer
Stderr io.Writer
}
Dependencies holds all the dependencies for commands
func DefaultDependencies ¶ added in v0.3.1
func DefaultDependencies() *Dependencies
DefaultDependencies returns the default dependencies
type EndCommand ¶ added in v0.3.1
type EndCommand struct {
// contains filtered or unexported fields
}
EndCommand handles the end command logic
func NewEndCommand ¶ added in v0.3.1
func NewEndCommand(deps *Dependencies, force, noFetch bool) *EndCommand
NewEndCommand creates a new end command handler
func NewEndCommandWithConfig ¶ added in v0.4.0
func NewEndCommandWithConfig(deps *Dependencies, force, noFetch bool, cfg *config.Config) *EndCommand
NewEndCommandWithConfig creates a new end command handler with explicit config
func (*EndCommand) Execute ¶ added in v0.3.1
func (c *EndCommand) Execute(issueNumber string) error
Execute runs the end command
type InitCommand ¶ added in v0.4.0
type InitCommand struct {
// contains filtered or unexported fields
}
InitCommand handles the init command logic
func NewInitCommand ¶ added in v0.4.0
NewInitCommand creates a new init command handler
func NewInitCommandWithShell ¶ added in v0.4.0
func NewInitCommandWithShell(stdin io.Reader, stdout, stderr io.Writer, configPath, rcPath string) *InitCommand
NewInitCommandWithShell creates a new init command handler with custom shell rc path (for testing)
func (*InitCommand) Execute ¶ added in v0.4.0
func (c *InitCommand) Execute() error
Execute runs the init command
type ShellIntegrationCommand ¶ added in v0.4.0
type ShellIntegrationCommand struct {
// contains filtered or unexported fields
}
ShellIntegrationCommand handles the shell-integration command logic
func NewShellIntegrationCommand ¶ added in v0.4.0
func NewShellIntegrationCommand(stdout, stderr io.Writer) *ShellIntegrationCommand
NewShellIntegrationCommand creates a new shell integration command handler
func (*ShellIntegrationCommand) Execute ¶ added in v0.4.0
func (c *ShellIntegrationCommand) Execute() error
Execute runs the shell integration command
type StartCommand ¶ added in v0.3.1
type StartCommand struct {
// contains filtered or unexported fields
}
StartCommand handles the start command logic
func NewStartCommand ¶ added in v0.3.1
func NewStartCommand(deps *Dependencies, copyEnvs, noFetch bool) *StartCommand
NewStartCommand creates a new start command handler
func NewStartCommandWithConfig ¶ added in v0.4.0
func NewStartCommandWithConfig(deps *Dependencies, copyEnvs, noFetch bool, cfg *config.Config) *StartCommand
NewStartCommandWithConfig creates a new start command handler with explicit config
func (*StartCommand) Execute ¶ added in v0.3.1
func (c *StartCommand) Execute(issueNumber, baseBranch string) error
Execute runs the start command
type WorktreeStatus ¶ added in v0.6.0
type WorktreeStatus struct {
Info *git.WorktreeInfo
CanRemove bool
Warnings []string
}
WorktreeStatus holds the status of a worktree for the clean command